package bogqaai;

/**
 * Súgóablak az algoritmusok részletes leírásának megjelenítésére. Az ablak a
 * <i>javax.swing.JDialog</i> osztályból származik.
 *
 * @author Bognár Gergő, BOGQAAI.ELTE
 */
public class HelpDialog extends javax.swing.JDialog {
    /** Súgó leírásának címkéje. */
    private final javax.swing.JEditorPane helpLabel;
    /** Súgó leírásának befoglalója. */
    private final javax.swing.JScrollPane helpPane;

    /**
     * A súgóablak konstruktora, paramétere az őt létrehozó <i>Window</i>.
     *
     * @param window Szülőablak
     */
    public HelpDialog(java.awt.Window window){
        super(window);
        setDefaultCloseOperation(javax.swing.JDialog.DISPOSE_ON_CLOSE);
        setPreferredSize(new java.awt.Dimension(480, 480));

        helpLabel = new javax.swing.JEditorPane("text/html", null);
        helpLabel.setBorder(new javax.swing.border.EmptyBorder(10, 10, 10, 10));
        helpLabel.putClientProperty(javax.swing.JEditorPane.HONOR_DISPLAY_PROPERTIES, Boolean.TRUE);
        helpLabel.setEditable(false);
        helpLabel.setOpaque(false);
        helpPane = new javax.swing.JScrollPane();
        helpPane.setBorder(null);
        helpPane.setViewportView(helpLabel);
        setContentPane(helpPane);
        pack();
        setLocationRelativeTo(null);
    }

    /**
     * Súgó megjelenítése, paraméterei az ablak címe és a megjelenítendő leírás.
     *
     * @param title Ablak címe
     * @param text Megjelenítendő leírás
     */
    public void showHelp(String title, String text){
        setTitle(title);
        helpLabel.setText(text);
        java.awt.EventQueue.invokeLater(new Runnable() {
            @Override
            public void run() {
                helpPane.getVerticalScrollBar().setValue(0);
            }
        });
        setVisible(true);
    }
}
