package bogqaai;

/**
 * A főablak kezdőlap utáni vázát leíró felület. Grafikus,
 * <i>javax.swing.JPanel</i> leszármazott osztály, a NetBeans szerkesztőjével
 * készült. A váz tartalmazza a gráf megjelenítőt, a szerkesztőablakot és az
 * állapotsort.
 *
 * @author Bognár Gergő, BOGQAAI.ELTE
 */
public final class MainPanel extends javax.swing.JPanel {

    /**
     * Konstruktor, paraméterei a gráf megjelenítő és a szerkesztőablak
     * kezdeti tartalma.
     *
     * @param drawerPanel Gráf megjelenítő tartalma
     * @param editorPanel Szerkesztőablak tartalma
     */
    public MainPanel(javax.swing.JPanel drawerPanel, javax.swing.JPanel editorPanel){
        initComponents();
        drawPane.setViewportView(drawerPanel);
        editorPane.setViewportView(editorPanel);
        setEditor(editorPanel);
    }

    /**
     * A szerkesztőablak tartalmának beállítása.
     *
     * @param panel Szerkesztőablak új tartalma
     */
    public void setEditor(javax.swing.JPanel panel){
        editorPane.setViewportView(panel);
    }
    /**
     * Az állapotsor tartalmának beállítása.
     *
     * @param status Állapotsor új tartalma
     */
    public void setStatus(String status){
        statusLabel.setText(status + " ");
    }

    /**
     * A grafikus komponensek inicializálása a konstruktorban. Tartalmát a
     * NetBeans szerkesztője generálta.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.JSplitPane splitPane = new javax.swing.JSplitPane();
        drawPane = new javax.swing.JScrollPane();
        editorPane = new javax.swing.JScrollPane();
        javax.swing.JScrollPane statusPane = new javax.swing.JScrollPane();
        statusLabel = new javax.swing.JLabel();

        setPreferredSize(new java.awt.Dimension(800, 450));

        splitPane.setBorder(null);
        splitPane.setDividerLocation(-280);
        splitPane.setResizeWeight(1.0);
        splitPane.setAutoscrolls(true);
        splitPane.setContinuousLayout(true);

        drawPane.setBorder(javax.swing.BorderFactory.createBevelBorder(javax.swing.border.BevelBorder.LOWERED));
        splitPane.setLeftComponent(drawPane);

        editorPane.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        editorPane.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
        editorPane.setMinimumSize(new java.awt.Dimension(280, 6));
        splitPane.setRightComponent(editorPane);

        statusPane.setBorder(null);
        statusPane.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        statusPane.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);

        statusLabel.setText(" "); // NOI18N
        statusPane.setViewportView(statusLabel);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(statusPane, javax.swing.GroupLayout.DEFAULT_SIZE, 780, Short.MAX_VALUE)
                    .addComponent(splitPane, javax.swing.GroupLayout.PREFERRED_SIZE, 0, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(splitPane, javax.swing.GroupLayout.DEFAULT_SIZE, 408, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(statusPane, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    /** Gráf megjelenítő. */
    private javax.swing.JScrollPane drawPane;
    /** Szerkesztőablak. */
    private javax.swing.JScrollPane editorPane;
    /** Állapotsor. */
    private javax.swing.JLabel statusLabel;
    // End of variables declaration//GEN-END:variables
}
