package bogqaai.graph.algorithm;

import bogqaai.graph.*;

/**
 * Az absztrakt adatszerkezet osztály, az adatszerkezet osztályok őse, az
 * absztrakt gráf osztályból származik. Az ősosztály funkcionalitása mellett
 * egy rajzolás műveletet tartalmaz, amit a leszármazott osztályok a saját
 * kirajzolásukra használhatnak fel.
 *
 * @author Bognár Gergő, BOGQAAI.ELTE
 */
public abstract class AbstractData extends AbstractGraph {
    /**
     * Az adatszerkezetet kirajzoló belső osztály, a gráf elemeit kirajzoló
     * absztrakt osztály leszármazottja. Definiálja a rajzolás paramétereit.
     */
    protected class DataDrawer extends Drawer {
        /** Az elemeket megjelenítő kör alapértelmezett sugara. */
        public static final int RADIUS = 12;
        /** Az elemek alapértelmezett távolsága. */
        public static final int DISTANCE = 30;

        /**
         * A rajzoló osztály konstruktora, paramétere a rajzolási cél.
         * Beállítja a rajzolás paramétereit.
         *
         * @param g A rajzolási cél
         */
        public DataDrawer(java.awt.Graphics2D g){
            this(g, RADIUS, RADIUS, false);
        }
        /**
         * A rajzoló osztály konstruktora, paramétere a rajzolási cél és a
         * rajzolás beállításai.
         *
         * @param g A rajzolási cél
         * @param radiusX Csúcsokat megjelenítő ellipszis vízszintes nagysága
         * @param radiusY Csúcsokat megjelenítő ellipszis függőleges nagysága
         * @param multiLineVertex A csúcsok szöveges több sort tartalmaz-e
         */
        public DataDrawer(java.awt.Graphics2D g, int radiusX, int radiusY, boolean multiLineVertex){
            super(g, true, radiusX, radiusY, multiLineVertex, 12, 6, 1, 1);
        }
    }

    /**
     * Az absztrakt adatszerkezet osztály konstruktora.
     */
    public AbstractData(){
        drawerBorderX = drawerBorderY = Drawer.BORDER + DataDrawer.RADIUS;
    }

    /**
     * Adatszerkezet kirajzolása, a leszármazott osztályokban felülírható
     * metódus. Visszatérési értéke a rajzoló objektum.
     *
     * @param g A rajzolási cél
     * @return A rajzoló objektum
     */
    public Drawer draw(java.awt.Graphics2D g){
        return new DataDrawer(g);
    }
}
