package bogqaai.graph.algorithm;

import bogqaai.graph.*;

/**
 * A Prim algoritmust megvalósító osztály, őse az absztrakt algoritmus osztály.
 *
 * @author Bognár Gergő, BOGQAAI.ELTE
 */
public final class Prim extends Algorithm {
    /**
     * A csúcsokhoz hozzárendelt adatok az algoritmus futása során: megelőző
     * csúcs és az erdőtől vett távolság.
     */
    private class Data implements Comparable<Data>{
        /** Erdőtől vett távolság. */
        private Integer d = null;
        /** Megelőző csúcs. */
        private Graph.Vertex p = null;


        /**
         * Összehasonlító operátor a távolságok rendezésére. A <i>d</i> adattag
         * <i>null</i> értéke a végtelent reprezentálja.
         *
         * @param o Másik adat
         * @return Összehasonlítás
         */
        @Override
        public int compareTo(Data o){
            if(d == null){
                return o.d == null ? 0 : 1;
            }else{
                return o.d == null ? -1 : d.compareTo(o.d);
            }
        }

        /**
         * Az erdőtől vett távolság feliratként. A feliraton szerepelhet a
         * végtelen.
         *
         * @return Felirat
         */
        @Override
        public String toString(){
            return d == null ? "\u221e" : d.toString();
        }
    }

    /** Inicializáló lépés. */
    private static final String initMessage = bundle.getString("Prim.init.message");
    /** Sikeres lefutás eredménye. */
    private static final String resultMessage = bundle.getString("Prim.success.message");
    /** Lépés. */
    private static final String stepMessage = bundle.getString("Prim.step.message");
    /** Lépés él behúzásával. */
    private static final String stepParentMessage = bundle.getString("Prim.stepparent.message");

    /** Kupac adatszerkezet. */
    private final Heap heap;
    /** Előzőleg vizsgált csúcs. */
    private Graph.Vertex last = null;

    /**
     * A Prim algoritmus konstruktora, paramétere a vizsgált gráf.
     *
     * @param graph Vizsgált gráf
     */
    public Prim(Graph graph){
        super(graph);
        heap = new Heap(graph);
        data = heap;
    }

    /**
     * Az algoritmus használja az élsúlyokat, visszatérési értéke igaz.
     *
     * @return Igaz
     */
    @Override
    public boolean isGraphWeighted() {
        return true;
    }

    /** Az algoritmus alaphelyzetbe állítása. */
    @Override
    protected String internalReset(){
        for(Graph.Vertex u: graph.getVertices()){
            u.data = new Data();
        }
        heap.fill();
        last = null;
        return initMessage;
    }

    /** Az algoritmus léptetése. */
    @Override
    protected String internalStep(){
        String resultText;
        if(last != null){
            last.set(last.getColor(), 0);
            last = null;
        }
        if(!heap.isEmpty()){
            Graph.Vertex u = heap.pop();
            if(((Data)u.data).d == null){
                ((Data)u.data).d = 0;
            }
            int type = 0;
            Graph.Vertex p = ((Data)u.data).p;
            if(p != null){
                resultText = java.text.MessageFormat.format(stepParentMessage, u.toString(), p.toString());
                Graph.Edge e = graph.getEdge(u, p);
                e.set(Graph.Color.BLUE, 0, e.getVertexU()==p ? Graph.Animation.LTR : Graph.Animation.RTL);
                type = Graph.Animation.DELAYED;
            }else{
                resultText = java.text.MessageFormat.format(stepMessage, u.toString());
            }
            u.set(0, Graph.Fill.MARKED, type);
            for(Graph.Vertex v: graph.getVertices()){
                Graph.Edge e = graph.getEdge(u, v);
                if(v.getColor() == Graph.Color.GRAY && e != null && (((Data)v.data).d == null || e.getWeight() < ((Data)v.data).d)){
                    ((Data)v.data).d = e.getWeight();
                    ((Data)v.data).p = u;
                    heap.itemChanged(v);
                }
            }
            last = u;
        }else{
            resultText = resultMessage;
            result = SUCCESS;
            heap.reset();
        }
        return resultText;
    }
}
