package bogqaai.graph.event;

import bogqaai.graph.*;

/**
 * A gráf megváltozása eseményt leíró osztály. Tartalmazza az eseményt kiváltó
 * absztrakt gráfot és az animáció állását. Az animáció állása 0 és 1 közötti
 * lebegőpontos szám lehet, ha az esemény nem animált, akkor értéke 1.
 *
 * @author Bognár Gergő, BOGQAAI.ELTE
 */
public class GraphEvent extends java.util.EventObject {
    /** Animáció állása. */
    private final float percent;

    /**
     * Az esemény osztály konstruktora, gráf megváltozása esetén. Paramétere
     * az absztrakt gráf, az animáció állását 1-re állítja.
     *
     * @param source Absztrakt gráf
     */
    public GraphEvent(AbstractGraph source){
        this(source, 1);
    }
    /**
     * Az esemény osztály konstruktora, gráf megváltozása esetén. Paramétere
     * az absztrakt gráf és az animáció állása.
     *
     * @param source Absztrakt gráf
     * @param percent Animáció állása
     */
    public GraphEvent(AbstractGraph source, float percent){
        super(source);
        this.percent = percent;
    }

    /**
     * Animáció állásának lekérdezése.
     *
     * @return Animáció állása
     */
    public float getPercent(){
        return percent;
    }
}
